changeset 9:2eceeda82a9f

from gentoo on ibook
author kent <kent@cr.ie.u-ryukyu.ac.jp>
date Sun, 16 Aug 2009 14:30:17 +0900
parents 14ed303f82b7 (diff) 9e31f478c3eb (current diff)
children 4bf4065677ef
files Xdefaults bcrc fetchmailrc muttrc procmailrc xinitrc zshrc
diffstat 9 files changed, 84 insertions(+), 82 deletions(-) [+]
line wrap: on
line diff
--- a/Xdefaults	Wed Jul 08 15:50:47 2009 +0900
+++ b/Xdefaults	Sun Aug 16 14:30:17 2009 +0900
@@ -34,17 +34,13 @@
 
 
 !! RXVT
-<<<<<<< local
-URxvt*font: xft:Kochi Gothic:antialias=true:size=10:spacing=20
-=======
-URxvt*font: xft:Kochi Gothic:antialias=true:size=11:spacing=20, \
-	xft:Dejavu Sans Mono
->>>>>>> other
+URxvt*font: xft:Kochi Gothic:antialias=true:size=9
+!URxvt*font: xft:Kochi Gothic:antialias=true:size=9, \
+	!xft:Dejavu Sans Mono
+!URxvt*font: xft:Kochi Gothic:antialias=true:size=11:spacing=20, \
+	!xft:Dejavu Sans Mono
 !URxvt*font: xft:IPAGothic-14:antialias=true
-<<<<<<< local
-URxvt*lineSpace: 1
-=======
->>>>>>> other
+!URxvt*lineSpace: 1
 URxvt*foreground: White
 URxvt*background: Black
 URxvt*termName: xterm
--- a/bcrc	Wed Jul 08 15:50:47 2009 +0900
+++ b/bcrc	Sun Aug 16 14:30:17 2009 +0900
@@ -13,6 +13,9 @@
 define cos(a){
 	return c(a)
 }
+define tan(a){
+	return s(a)/c(a)
+}
 define exp(a){
 	return e(a)
 }
--- a/fetchmailrc	Wed Jul 08 15:50:47 2009 +0900
+++ b/fetchmailrc	Sun Aug 16 14:30:17 2009 +0900
@@ -8,5 +8,4 @@
     protocol imap
     user "kent"
     ssl
-    #keep
 
--- a/install.cfg	Wed Jul 08 15:50:47 2009 +0900
+++ b/install.cfg	Sun Aug 16 14:30:17 2009 +0900
@@ -3,21 +3,28 @@
 ETCDIR: a
 
 [InstallFiles]
-
-# rcファイル指定ができない or したくないもの
-Xdefaults:	SYM
-xinitrc:	SYM
-hgrc:		SYM
-screenrc:	SYM
-bcrc:		SYM
-dir_colors:	SYM
-muttrc:		SYM
-procmailrc:	SYM
-vimrc:		SYM
-zshenv:		SYM
-zshrc:		SYM
-
-fetchmailrc:	LNK
+# filename	[dir/]linkname[,HARD|SYM]
+screenrc:		.screenrc
+bcrc:			.bcrc
+dir_colors:		.dir_colors
+fetchmailrc:	.fetchmailrc,HARD
+muttrc:			.muttrc
+vimrc:			.vimrc
+zshenv:			.zshenv
+zshrc:			.zshrc
+Xdefaults:		.Xdefault
+xinitrc:		.xinitrc
+hgrc:			.hgrc
+bash_profile:	.bash_profile
+bashrc:			.bashrc
+emacs:			.emacs
+inputrc:		.inputrc
+jvimrc:			.jvimrc
+login:			.login
+login_conf:		.login_conf
+profile:		.profile
+shrc:			.shrc
+tcshrc:			.tcshrc
 
 # 環境変数でファイル指定可能なもの
 #screenrc:		ENV:SCREENRC
--- a/muttrc	Wed Jul 08 15:50:47 2009 +0900
+++ b/muttrc	Sun Aug 16 14:30:17 2009 +0900
@@ -39,7 +39,8 @@
 set record = "$folder/sent"
 set postponed = "$folder/postponed"
 set include = yes
-set smtp_url = smtp://k088511@nirai.ie.u-ryukyu.ac.jp:587/
+#set smtp_url = smtp://k088511@nirai.ie.u-ryukyu.ac.jp:587/
+set smtp_url = smtps://kent@sanya.cr.ie.u-ryukyu.ac.jp:465/
 ## 最初はmsmtpを使ってたんだけど、必要ないっぽい。smtp_urlがあればignored
 #set sendmail = "/opt/local/bin/msmtp -a nirai"
 
--- a/xinitrc	Wed Jul 08 15:50:47 2009 +0900
+++ b/xinitrc	Sun Aug 16 14:30:17 2009 +0900
@@ -1,6 +1,9 @@
 #!/bin/sh
 # $Xorg: xinitrc.cpp,v 1.3 2000/08/17 19:54:30 cpqbld Exp $
 
+if [ -f $HOME/.Xmodmap ]; then
+    /usr/bin/xmodmap $HOME/.Xmodmap
+fi
 
 # japanese input method
 LANG="ja_JP.UTF-8" scim -d
@@ -8,14 +11,23 @@
 export GTK_IM_MODULE="scim"
 
 # terminals
-urxvt &
-urxvt &
+export RXVT_SOCKET=$HOME/.rxvt_socket
+#urxvt &
+#urxvt &
+urxvtd -q -o&
+#urxvtc
 
 # skippy
-skippy &
+#skippy &
 
+# pinboard of rox filemanager for background
+rox --pinboard=Default
+
+#xterm & 
 # window manager
 exec startfluxbox
+#exec twm
+#xterm
 
 if [ -f "$usermodmap" ]; then
     xmodmap "$usermodmap"
--- a/zshenv	Wed Jul 08 15:50:47 2009 +0900
+++ b/zshenv	Sun Aug 16 14:30:17 2009 +0900
@@ -1,6 +1,6 @@
 # System-wide .login file for csh(1).
 
-export PATH="$HOME/opt/bin:/usr/local/bin:/usr/X11R6/bin:/bin:/sbin:/usr/bin:/usr/sbin"
+export PATH="/usr/local/bin:/usr/X11R6/bin:/bin:/sbin:/usr/bin:/usr/sbin"
 export MANPATH=/usr/local/man:`manpath`
 #export DYLD_FALLBACK_LIBRARY_PATH="${HOME}/usr/lib"
 #export DYLD_FRAMEWORK_PATH="/Library/Frameworks:/System/Library/Frameworks"
--- a/zshrc	Wed Jul 08 15:50:47 2009 +0900
+++ b/zshrc	Sun Aug 16 14:30:17 2009 +0900
@@ -1,5 +1,7 @@
 # このファイルは対話的シェルで読み込まれる
 # this file will be loaded by interractive shell
+#
+PATH="$HOME/opt/bin:$HOME/opt/scripts:$PATH"
 
 # Lines configured by zsh-newuser-install
 HISTFILE=~/.zsh_history
@@ -52,7 +54,7 @@
 export ZLS_COLORS="$LS_COLORS" 
 
 
-disable mkdir
+#disable mkdir
 
 # zsh read followed files
 #  /etc/zshenv, $ZDOTDIR/.zshenv
--- a/symlink.py	Wed Jul 08 15:50:47 2009 +0900
+++ b/symlink.py	Sun Aug 16 14:30:17 2009 +0900
@@ -4,7 +4,7 @@
 import re
 import os
 import sys
-import ConfigParser
+import configparser
 
 home = os.environ['HOME']
 etcdir = os.getcwd()
@@ -13,64 +13,46 @@
 
 def main():
 	# read configuration file
-	config = ConfigParser.ConfigParser()
+	config = configparser.ConfigParser()
 	config.read( 'install.cfg')
-	opts = config.items('InstallFiles', 0)
+
+	for target in sys.argv[1:]:
+
+		value = config.get('InstallFiles', target)
+		(linkname, *opts) = value.split(",");
 
-	# loop all options
-	for opt in opts:
-		value = opt[1].split(':')
-		if value[0] == "SYM":
-			if len(value) > 1:
-				makeSymlink(opt[0], value[1])
-			else:
-				makeSymlink(opt[0])
-		elif value[0] == "LNK":
-			if len(value) > 1:
-				makeHardlink(opt[0], value[1])
-			else:
-				makeHardlink(opt[0])
+		hard = False
+		for opt in opts:
+			if opt=="HARD": hard = True
+
+		print(linkname, hard)
+
+		#makelink(target, linkname, hard)
 
 
-### make symbolic link dst0 relating with src0
-def makeSymlink(src0, dst0=None):
+### make symbolic or hard link dst0 relating with src0
+def makelink(target0, linkname0=None, hard=False):
 	# correct filename of source and destination
-	if dst0==None:
-		dst0 = "."+src0
-	src = dir+"/"+src0
-	dst = home+"/"+dst0
+	if linkname0==None:
+		linkname0 = "."+target0
+	target = dir+"/"+target0
+	linkname = home+"/"+linkname0
 
 	# check destination file
-	if os.path.exists(dst):
+	if os.path.exists(linkname):
 		if force:
-			os.remove(dst)
+			os.remove(linkname)
 		else:
-			print "file "+dst+" already existed!"
+			print("file "+linkname+" already existed!")
 			return
 
 	# make symbolic link
-	print dst+" => "+src
-	os.symlink(src, dst)
-
-### make hardlink dst0 relating with src0
-def makeHardlink(src0, dst0=None):
-	# correct filename of source and destination
-	if dst0==None:
-		dst0 = "."+src0
-	src = src0
-	dst = home+"/"+dst0
+	print(linkname+" => "+target)
+	if hard:
+		os.link(target, linkname)
+	else:
+		os.symlink(src, linkname)
 
-	# check destination file
-	if os.path.exists(dst):
-		if force:
-			os.remove(dst)
-		else:
-			print "file "+dst+" already existed!"
-			return
-
-	# make symbolic link
-	print dst+" => "+src
-	os.link(src, dst)
 
 main()
 
@@ -94,7 +76,7 @@
 	result = re.match( "DoT-(.*)", filename);
 	if result!=None:
 		dst = result.group(1)
-		print filename+" => "+dst
+		print(filename+" => "+dst)
 		os.rename(filename, dst)
 	
 #listingFromDir()
@@ -109,10 +91,10 @@
 #listing( master, 20 )
 def listing(a, b):
 	i=0;
-	print "b = "+str(b)
-	print "len(a) = "+str(len(a))
+	print("b = "+str(b))
+	print("len(a) = "+str(len(a)))
 	while i<len(a):
-		print "a["+str(i)+"] = "+str(a[i])
+		print( "a["+str(i)+"] = "+str(a[i]))
 		a[i] = a[i] + 5
 		i = i+1
 